summaryrefslogtreecommitdiffstats
path: root/certmanager/conf/appearanceconfigwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/conf/appearanceconfigwidget.cpp')
-rw-r--r--certmanager/conf/appearanceconfigwidget.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/certmanager/conf/appearanceconfigwidget.cpp b/certmanager/conf/appearanceconfigwidget.cpp
index 77a97bb4..33f4189b 100644
--- a/certmanager/conf/appearanceconfigwidget.cpp
+++ b/certmanager/conf/appearanceconfigwidget.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -63,7 +63,7 @@
using namespace Kleo;
-class CategoryListViewItem : public QListViewItem
+class CategoryListViewItem : public TQListViewItem
{
public:
CategoryListViewItem( TQListView* lv, TQListViewItem* prev, const KConfigBase& config )
@@ -114,7 +114,7 @@ public:
TQFont font() const { return mFont; }
void setDefaultAppearance() {
- mForegroundColor = mIsExpired ? Qt::red : TQColor();
+ mForegroundColor = mIsExpired ? TQt::red : TQColor();
mBackgroundColor = TQColor();
mHasFont = false;
mFont = TQFont();
@@ -178,8 +178,8 @@ void CategoryListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, in
////
Kleo::AppearanceConfigWidget::AppearanceConfigWidget (
- TQWidget* parent, const char* name, WFlags fl )
- : AppearanceConfigWidgetBase( parent, name, fl )
+ TQWidget* tqparent, const char* name, WFlags fl )
+ : AppearanceConfigWidgetBase( tqparent, name, fl )
{
categoriesLV->setSorting( -1 );
load();
@@ -192,7 +192,7 @@ Kleo::AppearanceConfigWidget::AppearanceConfigWidget (
AppearanceConfigWidget::~AppearanceConfigWidget()
{
// no need to delete child widgets, Qt does it all for us
}
@@ -192,7 +192,7 @@ Kleo::AppearanceConfigWidget::AppearanceConfigWidget (
AppearanceConfigWidget::~AppearanceConfigWidget()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}